# square_file_store

## about

file storage layer for my personal server.

## installation

```shell
pip install square_file_store
```

## env

- python>=3.12.0

## changelog

### v2.0.0

- rearrange file structure.
- add versions to all api endpoints.
- standard output for json outputs.
- replace hardcoded column names with variables from square_database_structure.
- update tests.
- refactor some code logic.

### v1.0.1

- replace file_purpose with app_id.

### v1.0.0

- initial implementation.

## Feedback is appreciated. Thank you!